sqlobject.tests.test_sqlbuilder_dbspecific module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_sqlbuilder_dbspecific module

class `sqlobject.tests.test_sqlbuilder_dbspecific.` `SBButton`(**kw)

  Bases: `sqlobject.main.SQLObject`

  property `activated`
  `j` = sb_button
  `q` = sb_button
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_sqlbuilder_dbspecific.SBButton`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'sb_button'

`sqlobject.tests.test_sqlbuilder_dbspecific.` `checkCount`(q, c, msg='')

`sqlobject.tests.test_sqlbuilder_dbspecific.` `makeClause`()

`sqlobject.tests.test_sqlbuilder_dbspecific.` `makeSelect`()

`sqlobject.tests.test_sqlbuilder_dbspecific.` `testAliased`()

`sqlobject.tests.test_sqlbuilder_dbspecific.` `testMiscOps`()

`sqlobject.tests.test_sqlbuilder_dbspecific.` `testSimple`()

`sqlobject.tests.test_sqlbuilder_dbspecific.` `testTablesUsedSResults`()